@@ -7,6 +7,10 @@ import os
 pasta_do_projeto = os.path.dirname( os.path.abspath(__file__) )
 pasta_das_imagens = pasta_do_projeto
 
+#tempo em segundos para a tela fechar
+#Evita erro quando houverem loops no código do jogo
+#pode ser alterado pelo usuário
+tempo_para_fechar_tela = 1
 pausado = False
 pygame.init()
 ##O pygame.time.Clock().tick( frequência ) deve ser sempre usado em
@@ -119,12 +123,44 @@ preto = pygame.color.THECOLORS['black']
 branco = pygame.color.THECOLORS['white']
 
 
-#algumas direçoes
-para_esquerda = [-1,0]
-para_direita = [1,0]
-para_cima = [0,-1]
-para_baixo = [0,1]
-direcao_nula = [0,0]
+#Direçoes
+
+class Direcao():
+    def __init__(self, direcao):
+        self._direcao = direcao
+    def __len__( self ):
+        return len(self._direcao)
+        
+    def __repr__( self ):
+        return str(self._direcao)
+    
+    def __str__( self ):
+        return self.__repr__()
+    
+    def somar_elementos( self, a, b ):
+        if( a == b ):
+            return a
+        else:
+            return a + b
+        
+    def __getitem__(self, indice):
+        return self._direcao[indice]
+    
+    def __add__(self, direcao):
+        direcao_soma = []
+        for i in range(len(direcao)):
+            soma = self.\
+                   somar_elementos\
+                   (self._direcao[i],\
+                    direcao._direcao[i])
+            direcao_soma.append(soma)
+        return Direcao(direcao_soma)
+    
+para_esquerda = Direcao([-1,0])
+para_direita = Direcao([1,0])
+para_cima = Direcao([0,-1])
+para_baixo = Direcao([0,1])
+direcao_nula = Direcao([0,0])
 
 #define gravidade do programa e aplica nos objetos
 gravidade = 10
@@ -591,6 +627,7 @@ class Botao():
     #Mostra se o botão está sendo pressionado.
     @property
     def pressionado(self):
+        '''indica se o botão está ou não sendo  pressionado'''
         if( self.rect.collidepoint(pygame.mouse.get_pos()) and
             pygame.mouse.get_pressed()[0]):
             return True
@@ -611,6 +648,7 @@ class Texto():
 
     @property
     def posicao(self):
+        '''Posição da extremidade esquerda superior do texto'''
         return [self.x,self.y]
     @posicao.setter
     def posicao(self, posicao):
@@ -619,11 +657,13 @@ class Texto():
     
     @property
     def fonte(self):
+        '''Tipo de fonte ( usado dentro da classe )'''
         return pygame.font.Font(self.tipo_de_fonte,
                                 self.tamanho_da_fonte)
 
     @property
     def texto(self):
+        ''' Dados do texto e cor do texto que serão exibidos '''
         return self.fonte.render( str(self.mensagem), True, self.cor)
 
 #Define o que será feito o iniciar a tela
@@ -637,10 +677,12 @@ class Tela():
 
     @property
     def largura(self):
+        '''largura da tela'''
         return self._largura
         
     @property
     def altura(self):
+        '''altura da tela'''
         return self._altura
 
 def atualizar_tela():
@@ -693,6 +735,9 @@ def verificar_eventos():
                         acao.join()
                     #espera threading da tela
                     #t_atualizar_tela.join()
+                    #Espera um pouco antes de fechar tela para
+                    #os loops do usuário finalizarem
+                    time.sleep( tempo_para_fechar_tela )
                     pygame.display.quit()
                     #fecha a tela
                     pygame.quit()
